from django.test import TestCase, Client
from django.contrib.auth.models import Permission
from knox.models import AuthToken

from authentication.models import ExtendedUser


class ApiTest(TestCase):

    def setUp(self):
        super().setUp()
        self.user = ExtendedUser.objects.create_user('testuser', 'test', 'test')
        self.user.user_permissions.add(*Permission.objects.all())
        self.user.save()
        self.token = AuthToken.objects.create(user=self.user)
        self.client = Client(headers={'Authorization': 'Token ' + self.token[1]})

    def test_root(self):
        from core.settings import SYSTEM3_VERSION
        response = self.client.get('/api/')
        self.assertEqual(response.status_code, 200)
        self.assertEqual(response.json()["framework_version"], SYSTEM3_VERSION)

    def test_events(self):
        response = self.client.get('/api/2/events/')
        self.assertEqual(response.status_code, 200)
        self.assertEqual(response.json(), [])

    def test_containers(self):
        response = self.client.get('/api/2/boxes/')
        self.assertEqual(response.status_code, 200)
        self.assertEqual(response.json(), [])

    def test_files(self):
        response = self.client.get('/api/2/files/')
        self.assertEqual(response.status_code, 200)
        self.assertEqual(response.json(), [])

    def test_items(self):
        from inventory.models import Event
        Event.objects.create(slug='TEST1', name='Event')
        response = self.client.get('/api/2/TEST1/items/')
        self.assertEqual(response.status_code, 200)
        self.assertEqual(response.json(), [])
